@@ -22,20 +22,20 @@ from polly.help import example, doc
 import polly.http_response_codes as http_codes
 from polly.constants import SUPPORTED_ENTITY_TYPES, CURATION_COHORT_CACHE
 from polly.helpers import get_cohort_constants
+from polly.tracking import Track
 
 
 class Curation:
     """
     The Curation class contains wrapper functions around the models used for
-    semantic annotations of string/text
+    semantic annotations of string/text.
     Args:
         token (str): token copy from polly.
 
     Usage:
             from polly.curation import Curation
-            curationObj = Curation(token)
 
-    If you are authorised then you can initialize object without token to know about :ref:`authentication <auth>`.
+            curationObj = Curation(token)
     """
 
     Tag = namedtuple("Tag", ["name", "ontology_id", "entity_type"])
@@ -77,7 +77,7 @@ class Curation:
             dataset_ids (List[str]): dataset ids to be used for inference
 
         Returns:
-            Returns sample metadata, dataset and sample ids
+            Returns sample metadata, dataset and sample ids.
         """
         sample_metadata = {}
         dataset_to_sample_id = {"dataset_id": [], "sample_id": []}
@@ -138,14 +138,15 @@ class Curation:
         sample_ids: Optional[List[str]] = None,
     ):
         """
-        checking the parameter passed for the clincal label assigning model
+        Checking the parameter passed to the clinical label assigning model.
 
         Arguments:
-            repo_name(str): repo name
+            repo_name (str): repo name
             dataset_ids (list[str]): list of dataset ids
 
         Keyword Arguments:
-            sample_ids (list[str]): list of sample ids (default: {None})
+            sample_ids (list[str], optional): Optional Parameter. List of sample ids.
+            Default is 'None'.
 
         Raises:
             paramException
@@ -242,7 +243,7 @@ class Curation:
         """
         This is a wrapper around model inference APIs
         It serializes input_data, calls the API for the given model_name
-        and returns deserialized output
+        and returns deserialized output.
 
         Args:
             model_name (str): one of 'normalizer', 'biobert' and 'control-perturbation'
@@ -269,6 +270,7 @@ class Curation:
             return response.get("data")
         return response
 
+    @Track.track_decorator
     @lru_cache(maxsize=None)
     def standardise_entity(
         self,
@@ -277,21 +279,25 @@ class Curation:
         context: Optional[str] = None,
         threshold: Optional[float] = None,
     ) -> dict:
-        """Map a given mention (keyword) to an ontology term.
+        """
+        Map a given mention (keyword) to an ontology term.
         Given a text and entity type, users can get the Polly compatible ontology for the text such as the MESH ontology.
 
         Args:
             mention (str): mention of an entity e.g. "Cadiac arrythmia"
-            entity_type (str): Should be one of
+            entity_type (str): Should be one of\
             ['disease', 'drug', 'tissue', 'cell_type', 'cell_line', 'species', 'gene']
-            context (str): The text where the mention occurs.
-            This is used to resolve abbreviations
+            context (str): The text where the mention occurs.\
+            This is used to resolve abbreviations.
+            Threshold: (float, optional) = Optional Parameter. \
+            All entities with a score < threshold are filtered out from the output. \
+            Its best not to specify a threshold and just use the default value instead.
 
         Returns:
             dict : Dictionary containing keys and values of the entity type,
             ontology (such as NCBI, MeSH), ontology ID (such as the MeSH ID), the score (confidence score), and synonyms if any
         Raises:
-                requestException : Invalid Request
+            requestException : Invalid Request
         """
         data = {
             "mention": {
@@ -318,24 +324,29 @@ class Curation:
 
         return output.get("term", [])
 
+    @Track.track_decorator
     def recognise_entity(
         self,
         text: str,
         threshold: Optional[float] = None,
         normalize_output: bool = False,
     ):
-        """Run an NER model on the given text. The returned value is a list of entities along with span info.
+        """
+        Run an NER model on the given text. The returned value is a list of entities along with span info.
         Users can simply recognise entities in a given text without any ontology standardisation
-        (unlike the annotate_with_ontology function which normalises as well).
+         (unlike the annotate_with_ontology function which normalises as well).
 
         Args:
-                text (str): input text
-                normalize_output (bool): whether to normalize the keywords
+            text (str): input text
+            threshold (float, optional): Optional Parameter. \
+            All entities with a score < threshold are filtered out from the output. \
+            Its best not to specify a threshold and just use the default value instead.\
+            normalize_output (bool): whether to normalize the keywords
 
         Returns:
             entities (List[dict]): List of spans containing the keyword, start/end index of the keyword and the entity type
         Raises:
-                requestException : Invalid Request
+            requestException : Invalid Request
         """
         # TODO: If text is too long, break it up into chunks small enough for biobert
 
@@ -369,16 +380,17 @@ class Curation:
                     entity["name"] = norm["name"]
         return entities
 
+    @Track.track_decorator
     def annotate_with_ontology(
         self,
         text: str,
     ) -> List[Tag]:
         """
         Tag a given piece of text. A "tag" is just an ontology term. Annotates with Polly supported ontologies.
-
         This function calls recognise_entity followed by normalize.
         Given a text, users can identify and tag entities in a text.
         Each entity/tag recognised in the text contains the name(word in the text identified), entity_type and the ontology_id.
+
         Args:
             text (str): Input text
         Returns:
@@ -395,18 +407,20 @@ class Curation:
         }
         return list(res)
 
+    @Track.track_decorator
     def find_abbreviations(self, text: str) -> Dict[str, str]:
         """
         To run abbreviation detection separately.
         Internally calls a normaliser.
 
-            Args:
-            text (str): The string to detect abbreviations in
+        Args:
+            text (str): The string to detect abbreviations in.
 
-            Returns:
-            Dictionary with abbreviation as key and full form as value
-            Raises:
-                    requestException : Invalid Request
+        Returns:
+        Dictionary with abbreviation as key and full form as value
+
+        Raises:
+            requestException : Invalid Request
         """
         data = {
             "mention": {"keyword": "dummykeyword", "entity_type": "gene"},
@@ -431,10 +445,10 @@ class Curation:
             is_control - whether the sample is a control sample
             control_prob - the probability that the sample is control
         Args:
-            sample_metadata (pandas.DataFrame): Metadata table
+            sample_metadata (DataFrame): Metadata table
             columns_to_exclude (Set[str]): Any columns which don't play any role in determining the label, e.g. sample id
         Returns:
-            DataFrame with input data frame with 2 additional columns
+            DataFrame : Input data frame with 2 additional columns
         Raises:
             requestException : Invalid Request
 
@@ -463,6 +477,7 @@ class Curation:
         sample_metadata["control_prob"] = output["control_prob"].values
         return sample_metadata
 
+    @Track.track_decorator
     def assign_clinical_labels(
         self,
         repo_name: str,
@@ -477,7 +492,7 @@ class Curation:
             dataset_ids (List[str]): dataset ids to be used for inference
 
         Keyword Arguments:
-            sample_ids (Optional[List[str]]): sample ids if that is needed
+            sample_ids (List[str], optional): Optional Parameter. Sample ids if that is needed.
 
         Raises:
             RequestException: API response exception
