@@ -21,6 +21,7 @@ from polly.helpers import (
 from polly.constants import COMPUTE_ENV_VARIABLE, DATA_LOG_MODES
 import polly.http_response_codes as http_codes
 from polly import constants as const
+from polly.tracking import Track
 
 import pandas as pd
 import os
@@ -59,17 +60,15 @@ class jobs:
 
     # project_id -> workspace_id
     # job_file -> json file
+    @Track.track_decorator
     def submit_job(self, project_id: str, job_file: str) -> pd.DataFrame:
         """
-        submits  a polly cli job in the given workspace
+        Submits  a polly cli job in the given workspace.
+        A message will be displayed on the status of the operation.
 
         Args:
-            project_id (str) :  workspace id : str
-            job_file (str) : required configuration json file path : str
-
-        Returns:
-            on success: dataframe with workspace id and job id
-            failure: throw errors
+            project_id (str):  workspace id
+            job_file (str): required configuration json file path
         """
         parameter_check_dict = {}
         parameter_check_dict["project_id"] = project_id
@@ -96,13 +95,14 @@ class jobs:
             submittedProject_df = pd.DataFrame([submittedProject])
         return submittedProject_df
 
+    @Track.track_decorator
     def cancel_job(self, project_id: str, job_id: str):
         """
         cancel a polly job.
 
         Args:
-            project_id (str) : workspace id : str
-            job_id (str) : job id
+            project_id (str): workspace id
+            job_id (str): job id
 
         Raises:
             InvalidParameterException
@@ -144,18 +144,19 @@ class jobs:
             print("Failed to cancel the job.")
             raise err
 
+    @Track.track_decorator
     def job_status(self, project_id: str, job_id="", internalCalls=False) -> dict:
         """
         Get the status of a job given the rproject id and job id.
         If no job id given, gives status for all the jobs in the
-        provided workspace
+        provided workspace.
 
         Args:
-            project_id (str) : workspace id
-            job_id (str) : job id
+            project_id (str): workspace id
+            job_id (str): job id
 
         Returns:
-            dataframe with job id, job name and status sorted as per created timestamp
+            DataFrame : Contains job id, job name and status sorted as per created timestamp
         """
         parameter_check_dict = {}
         parameter_check_dict["project_id"] = project_id
@@ -207,6 +208,7 @@ class jobs:
         #     print(status_result_df)
         return status_result_df
 
+    @Track.track_decorator
     def job_logs(self, project_id: any, job_id: str, mode="all"):
         """
         get logs of job
@@ -265,18 +267,17 @@ class jobs:
 
     def _get_job_log(self, project_id: str, job_id: str, next_token=None, latest=False):
         """
-        get the AWS signed url for the job logs
+        get the AWS signed url for the job logs.
+        Returns response (str) with signed url and next token for job logs
 
-        Arguments:
+        args:
             project_id (str/int): workspace id
             job_id (str): job id
 
-        Keyword Arguments:
+        **kwargs:
             next_token (str): token string to fetch data (default: {None})
             latest (bool) : get latest log (default: {False})
 
-        Returns:
-            response (str) with signed url and next token for job logs
         """
         logReturn = ""
         try:
